@@ -5,6 +5,7 @@ import random
 import socket
 import string
 import threading
+import time
 import types
 from _weakrefset import WeakSet
 from contextlib import closing
@@ -14,11 +15,11 @@ from unittest import TestCase
 from uuid import uuid4, UUID
 
 import orjson
-import time
 import zmq
 from pydantic import BaseModel, Field
 
-from openmodule.dispatcher import MessageDispatcher, SubscribingMessageDispatcher
+from openmodule.config import settings
+from openmodule.dispatcher import SubscribingMessageDispatcher
 from openmodule.utils.schema import Schema
 from openmodule_test.utils import DeveloperError
 
@@ -338,6 +339,13 @@ def fake_config(broker: Optional[TestBroker] = None, **kwargs):
     return config
 
 
+def find_free_port():
+    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
+        s.bind(('127.0.0.1', 0))
+        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+        return s.getsockname()[1]
+
+
 class _TestRPCRequest(BaseModel):
     """
     we do not want to depend on openmodule, this is a minimal version of the zmq message for the rpc function
@@ -354,13 +362,6 @@ class ZMQProcotol(str, Enum):
     tcp = "tcp://"
 
 
-def _find_free_port():
-    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
-        s.bind(('127.0.0.1', 0))
-        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-        return s.getsockname()[1]
-
-
 class ZMQTestMixin(TestCase):
     topics: List[Union[bytes, str]] = []
     rpc_channels: List[Union[bytes, str]] = []
@@ -371,17 +372,13 @@ class ZMQTestMixin(TestCase):
 
     def setUp(self):
         super(ZMQTestMixin, self).setUp()
+        assert self.protocol in ["tcp://", "inproc://"], "only tcp:// and inproc:// protocols are allowed"
+        if self.protocol == "tcp://" and not settings.BROKER_SUB.startswith("tcp"):
+            settings.override(BROKER_SUB=f"tcp://127.0.0.1:{find_free_port()}",
+                              BROKER_PUB=f"tcp://127.0.0.1:{find_free_port()}")
 
-        assert self.protocol in ["inproc://", "tcp://"]
-        if self.protocol == "inproc://":
-            random_suffix = "".join(random.choices(string.ascii_letters, k=10))
-            sub = f"inproc://test-sub-{random_suffix}"
-            pub = f"inproc://test-pub-{random_suffix}"
-        else:
-            sub = f"tcp://127.0.0.1:{_find_free_port()}"
-            pub = f"tcp://127.0.0.1:{_find_free_port()}"
+        self.zmq_broker = TestBroker(settings.BROKER_SUB, settings.BROKER_PUB)
 
-        self.zmq_broker = TestBroker(sub, pub)
         self.zmq_broker.start()
         self.zmq_client = TestClient(self.zmq_broker)
         self.zmq_client.start()
@@ -417,7 +414,8 @@ class ZMQTestMixin(TestCase):
         return self.zmq_broker.context
 
     def zmq_config(self, **kwargs):
-        return fake_config(self.zmq_broker, **kwargs)
+        settings.override(**kwargs)
+        return settings
 
     def tearDown(self):
         assert hasattr(self, "zmq_client"), (
@@ -427,6 +425,7 @@ class ZMQTestMixin(TestCase):
         self.zmq_client.stop()
         self.zmq_broker.stop()
         Schema.to_file()
+        settings.reset()
 
     def rpc(self, channel: str, type: str, request, timeout=3, receive_response=True) -> Optional[dict]:
         response_topic = f"rpc-rep-{channel}".encode("ascii")
