@@ -19,18 +19,16 @@ class AlertTestCase(AlertTestMixin, TestCase):
 
     def test_value_is_required_for_state(self):
         alert_handler = AlertHandler(self.core)
-        alert_handler.send("pin1", "some_alert", AlertHandleType.state, value=10)
+        alert_handler.send("some_alert", AlertHandleType.state, value=10, source="pin1")
         self.assertAlert()
 
         with self.assertRaises(ValueError) as e:
-            alert_handler.send("pin1", "some_alert", AlertHandleType.state)
+            alert_handler.send("some_alert", AlertHandleType.state, source="pin1")
         self.assertIn("value must not be none", str(e.exception).lower())
-
         self.assertNoAlert()
 
     def test_value_none_is_not_sent(self):
         alert_handler = AlertHandler(self.core)
-        alert_handler.send("pin1", "some_alert", AlertHandleType.state_change)
+        alert_handler.send("some_alert", AlertHandleType.state_change, source="pin1")
         alert = self.assertAlert(alert_type="some_alert")
-
         self.assertNotIn("value", alert)
