@@ -100,9 +100,11 @@ class ModelTest(TestCase):
 
     def test_check_recurrence_validator(self):
         cls = None
-        with self.assertRaises(ValueError) as e:
-            check_recurrence(cls, "", {})
-        self.assertIn("duration", str(e.exception))
+
+        # due to too much legacy data which contains "", we allow empty string, but it is converted to none internally
+        check_recurrence(cls, "", {})
+        access = Access(start=0, user="test", category=AccessCategory.permanent_digimon, recurrence="")
+        self.assertIsNone(access.recurrence)
 
         with self.assertRaises(ValueError) as e:
             check_recurrence(cls, "DTSTART\n", {"duration": "100"})
